# Lyrics-Predictor [![Build Status](https://travis-ci.com/Ayazdi/Lyrics-Predictor.svg?branch=master)](https://travis-ci.com/Ayazdi/Lyrics-Predictor)
A python program to scrape lyrics from any artist on metrolyrics.com and train a lyrics predictor model to predict which artist the given lyrics belongs.

contact = amirali.yazdi@yahoo.com

## Usage:
python lyrics_predictor.py

## Description:
- Enter names of two artists: program will scrape lyrics of the first two pages on the website and train a model on them

- Enter lyrics of a song: program will predict which artist it belongs and print the result.

